@@ -4,24 +4,24 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -59,11 +59,11 @@ dir(NULL)
 #endif
 {
 #ifdef HAVE_READDIR_R
-       save = reinterpret_cast<struct dirent*>(save_space);
+	   save = reinterpret_cast<struct dirent*>(save_space);
 #endif
 	if(fname)
 		open(fname);
-}
+	}
 
 bool Dir::create(const char *path, Attr attr)
 {
@@ -76,8 +76,7 @@ bool Dir::create(const char *path, Attr attr)
 	if(!CreateDirectory(path, NULL))
 		rtn = false;
 #else
-	switch(attr)
-	{
+	switch(attr) {
 	case attrPublic:
 		xmask |= S_IXOTH;
 	case attrGroup:
@@ -92,7 +91,7 @@ bool Dir::create(const char *path, Attr attr)
 		rtn = false;
 #endif
 	return rtn;
-}
+	}
 
 bool Dir::remove(const char *path)
 {
@@ -105,7 +104,7 @@ bool Dir::remove(const char *path)
 		rtn = false;
 #endif
 	return rtn;
-}
+	}
 
 bool Dir::setPrefix(const char *prefix)
 {
@@ -119,7 +118,7 @@ bool Dir::setPrefix(const char *prefix)
 		rtn = false;
 #endif
 	return rtn;
-}
+	}
 
 bool Dir::getPrefix(char *prefix, size_t size)
 {
@@ -133,7 +132,7 @@ bool Dir::getPrefix(char *prefix, size_t size)
 		rtn = false;
 #endif
 	return rtn;
-}
+	}
 
 void Dir::open(const char *fname)
 {
@@ -145,8 +144,7 @@ void Dir::open(const char *fname)
 	close();
 #ifdef WIN32
 	DWORD attr = GetFileAttributes(fname);
-	if( (attr == (DWORD)~0l) || !(attr & FILE_ATTRIBUTE_DIRECTORY) )
-	{
+	if( (attr == (DWORD)~0l) || !(attr & FILE_ATTRIBUTE_DIRECTORY) ) {
 #ifdef	CCXX_EXCEPTIONS
 		if(Thread::getException() == Thread::throwObject)
 			throw(this);
@@ -186,12 +184,12 @@ void Dir::open(const char *fname)
 #endif
 #endif
 #endif // WIN32
-}
-	
+	}
+
 Dir::~Dir()
 {
 	close();
-}
+	}
 
 void Dir::close(void)
 {
@@ -205,7 +203,7 @@ void Dir::close(void)
 	dir = NULL;
 	entry = NULL;
 #endif
-}
+	}
 
 bool Dir::rewind(void)
 {
@@ -216,11 +214,11 @@ bool Dir::rewind(void)
 #else
 	if(!dir)
 		rtn = false;
-	else 
+	else
 		rewinddir(dir);
 #endif
 	return rtn;
-}
+	}
 
 bool Dir::isValid(void)
 {
@@ -232,7 +230,7 @@ bool Dir::isValid(void)
 		return false;
 
 	return true;
-}
+	}
 
 const char *Dir::operator*()
 {
@@ -247,7 +245,7 @@ const char *Dir::operator*()
 
 	return entry->d_name;
 #endif
-}
+	}
 
 const char *Dir::getName(void)
 {
@@ -256,9 +254,8 @@ const char *Dir::getName(void)
 
 	if(hDir == INVALID_HANDLE_VALUE)
 		return NULL;
-	
-	if(retname)
-	{
+
+	if(retname) {
 		name = NULL;
 		if(FindNextFile(hDir, &data))
 			name = data.cFileName;
@@ -271,7 +268,7 @@ const char *Dir::getName(void)
 
 #ifdef	HAVE_READDIR_R
 	readdir_r(dir, save, &entry);
-#else 
+#else
 	entry = readdir(dir);
 #endif
 	if(!entry)
@@ -279,23 +276,23 @@ const char *Dir::getName(void)
 
 	return entry->d_name;
 #endif // WIN32
-}
+	}
 
 DirTree::DirTree(const char *prefix, unsigned depth)
 {
 	max = ++depth;
 	dir = new Dir[depth];
 	current = 0;
-	
+
 	open(prefix);
-}
+	}
 
 DirTree::DirTree(unsigned depth)
 {
 	max = ++depth;
 	dir = new Dir[depth];
 	current = 0;
-}
+	}
 
 void DirTree::open(const char *prefix)
 {
@@ -315,8 +312,8 @@ void DirTree::open(const char *prefix)
 	while(prefixpos && path[prefixpos - 1] == '/')
 		path[prefixpos--] = 0;
 
-	dir[current++].open(prefix);	
-}
+	dir[current++].open(prefix);
+	}
 
 DirTree::~DirTree()
 {
@@ -326,7 +323,7 @@ DirTree::~DirTree()
 		delete[] dir;
 
 	dir = NULL;
-}
+	}
 
 unsigned DirTree::perform(const char *prefix)
 {
@@ -337,7 +334,7 @@ unsigned DirTree::perform(const char *prefix)
 		++count;
 	close();
 	return count;
-}
+	}
 
 void DirTree::close(void)
 {
@@ -345,7 +342,7 @@ void DirTree::close(void)
 		dir[current].close();
 
 	current = 0;
-}
+	}
 
 
 bool DirTree::filter(const char *path, struct stat *ino)
@@ -367,7 +364,7 @@ bool DirTree::filter(const char *path, struct stat *ino)
 		return false;
 
 	return true;
-}
+	}
 
 char *DirTree::getPath(void)
 {
@@ -376,20 +373,17 @@ char *DirTree::getPath(void)
 	struct stat ino;
 	bool flag;
 
-	while(current)
-	{
+	while(current) {
 		cp = strrchr(path, '/');
 		name = dir[current - 1].getName();
-		if(!name)
-		{
+		if(!name) {
 			*cp = 0;
 			dir[--current].close();
 			continue;
 		}
 		snprintf(cp + 1, sizeof(path) - strlen(path) - 2, "%s", name);
-	
-		if(::stat(path, &ino))
-		{
+
+		if(::stat(path, &ino)) {
 			ino.st_mode = 0;
 			flag = filter(path, NULL);
 		}
@@ -399,8 +393,7 @@ char *DirTree::getPath(void)
 		if(!flag)
 			continue;
 
-		if((ino.st_mode & S_IFMT) == S_IFDIR)
-		{
+		if((ino.st_mode & S_IFMT) == S_IFDIR) {
 			if(!canAccess(path))
 				break;
 
@@ -414,8 +407,8 @@ char *DirTree::getPath(void)
 	if(!current)
 		return NULL;
 
-	return path;	
-}
+	return path;
+	}
 
 #ifdef	CCXX_NAMESPACES
 }
