@@ -13,15 +13,15 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -46,8 +46,8 @@
 namespace ost {
 #endif
 
-Exception::Exception(const String& what_arg) throw(): 
-  _what(what_arg) 
+Exception::Exception(const String& what_arg) throw():
+  _what(what_arg)
 { }
 
 Exception::~Exception() throw()
@@ -58,15 +58,14 @@ const char *Exception::what() const throw()
 	return _what.c_str();
 }
 
-const char *Exception::getString() const 
+const char *Exception::getString() const
 {
 	return _what.c_str();
 }
 
-IOException::IOException(const String &what_arg, long systemError) throw() : 
-	Exception(what_arg), _systemError(systemError), 
-	_systemErrorString(NULL)
-{
+IOException::IOException(const String &what_arg, long systemError) throw() :
+	Exception(what_arg), _systemError(systemError),
+	_systemErrorString(NULL) {
 }
 
 IOException::~IOException() throw()
