@@ -4,24 +4,24 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -112,23 +112,45 @@ void	Thread::yield(void)
 
 #ifdef	CCXX_SIG_THREAD_CANCEL
 
+#if defined(HAVE_PTHREAD_NANOSLEEP) || defined(HAVE_PTHREAD_DELAY)
+void    Thread::sleep(timeout_t timeout)
+{
+	struct timespec ts;
+	Cancel old = Thread::enterCancel();
+
+	ts.tv_sec = timeout / 1000;
+	ts.tv_usec = (timeout % 1000) * 1000000;
+#ifdef	HAVE_PTHREAD_DELAY
+	pthread_delay(&ts);
+#else
+	nanosleep(&ts);
+#endif
+	Thread::exitCancel(old);
+}
+#else
 void	Thread::sleep(timeout_t timeout)
 {
 	Cancel old = Thread::enterCancel();
 	usleep(timeout * 1000);
 	Thread::exitCancel(old);
 }
+#endif
 
 #else
 
-#ifdef HAVE_PTHREAD_DELAY
+#if defined(HAVE_PTHREAD_DELAY) || defined(HAVE_PTHREAD_NANOSLEEP)
 
 void	Thread::sleep(timeout_t timeout)
 {
 	struct timespec timer;
 	timer.tv_sec = timeout / 1000;
 	timer.tv_nsec = (timeout % 1000) * 1000000;
+
+#ifdef	HAVE_PTHREAD_DELAY
 	pthread_delay(&timer);
+#else
+	nanosleep(&timer);
+#endif
 }
 
 #else
