@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -88,11 +88,11 @@ static unsigned bitsize(void)
 	return 1;
 }
 
-Keydata::Keydata() : 
+Keydata::Keydata() :
 MemPager(KEYDATA_PAGER_SIZE * bitsize())
 {
 	link = 0;
-	memset(&keys, 0, sizeof(keys)); 
+	memset(&keys, 0, sizeof(keys));
 }
 
 Keydata::Keydata(const char *path) :
@@ -127,8 +127,7 @@ Keydata::Keysym *Keydata::getSymbol(const char *sym, bool create)
 	size_t len = strlen(sym) + 1;
 	Keysym *key = keys[path];
 
-	while(key)
-	{
+	while(key) {
 		if(!stricmp(sym, key->sym))
 			return key;
 		key = key->next;
@@ -222,8 +221,7 @@ bool Keydata::getBool(const char *sym)
 	if(!cp)
 		return false;
 
-	switch(*cp)
-	{
+	switch(*cp) {
 	case 'y':
 	case 'Y':
 	case 't':
@@ -260,11 +258,9 @@ unsigned Keydata::getCount(void)
 	Keysym *key;
 	int idx;
 
-	for(idx = 0; idx < KEYDATA_INDEX_SIZE; ++idx)
-	{
+	for(idx = 0; idx < KEYDATA_INDEX_SIZE; ++idx) {
 		key = keys[idx];
-		while(key)
-		{
+		while(key) {
 			++icount;
 			key = key->next;
 		}
@@ -278,13 +274,11 @@ unsigned Keydata::getIndex(char **data, unsigned max)
 	Keysym *key;
 	unsigned icount = 0;
 
-	for(idx = 0; idx < KEYDATA_INDEX_SIZE; ++idx)
-	{
+	for(idx = 0; idx < KEYDATA_INDEX_SIZE; ++idx) {
 		if(icount >= max)
 			break;
 		key = keys[idx];
-		while(key && icount < max)
-		{
+		while(key && icount < max) {
 			*(data++) = key->sym;
 			++icount;
 			key = key->next;
@@ -326,13 +320,11 @@ const char *const *Keydata::getList(const char *sym)
 		return NULL;
 
 	++icount;
-	if(!key->list)
-	{
+	if(!key->list) {
 		key->list =(const char **)first(sizeof(const char**) * icount);
 		key->list[--icount] = NULL;
 		data = key->data;
-		while(icount && data)
-		{
+		while(icount && data) {
 			key->list[--icount] = data->val;
 			data = data->next;
 		}
@@ -357,8 +349,7 @@ void Keydata::load(Define *defs)
 {
 	Keysym *key;
 
-	while(defs->keyword)
-	{
+	while(defs->keyword) {
 		key = getSymbol(defs->keyword, true);
 		if(!key->data)
 			setValue(defs->keyword, defs->value);
@@ -402,15 +393,13 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 		regprefix="";
 
 	ccp = keypath;
-	if(*ccp == '~')
-	{
+	if(*ccp == '~') {
 		++ccp;
 		if(*ccp == '/')
 			++ccp;
-		snprintf(path, sizeof(path), CAPE_REGISTRY_USERSETTINGS "/%s%s/", regprefix, ccp); 
+		snprintf(path, sizeof(path), CAPE_REGISTRY_USERSETTINGS "/%s%s/", regprefix, ccp);
 	}
-	else
-	{
+	else {
 		if(*ccp == '/')
 			++ccp;
 		snprintf(path, sizeof(path), CAPE_REGISTRY_APPLICATIONS "/%s%s/", regprefix, ccp);
@@ -428,10 +417,8 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 	// if registry key path is found, then we use registry values
 	// and ignore .ini files...
 
-	if(value == ERROR_SUCCESS)
-	{
-		for(;;)
-		{
+	if(value == ERROR_SUCCESS) {
+		for(;;) {
 			keynamelen = 256;
 			value = RegEnumKeyEx(key, keyindex, keyname, &keynamelen, NULL, NULL, NULL, NULL);
 			if(value != ERROR_SUCCESS)
@@ -443,8 +430,7 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 			if(value != ERROR_SUCCESS)
 				continue;
 
-			if(pre)
-			{
+			if(pre) {
 				snprintf(path, sizeof(path), "%s.%s", pre, keyname);
 				setValue(path, keytext);
 			}
@@ -465,8 +451,7 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 	if(ccp)
 		return;
 
-	if(*keypath == '~')
-	{
+	if(*keypath == '~') {
 		prefix = getenv("USERPROFILE");
 		if(!prefix)
 			return;
@@ -481,8 +466,7 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 
 #else
 
-	if(*keypath == '~')
-	{
+	if(*keypath == '~') {
 		prefix = getenv("HOME");
 		if(!prefix)
 			return;
@@ -494,17 +478,15 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 
 #endif
 
-	if(!prefix)
-	{
+	if(!prefix) {
 #ifdef	WIN32
 		if(!prefix || !*prefix)
 			prefix = registry.configdir;
-#else		
+#else
 
 retry:
 #ifdef	ETC_CONFDIR
-		if(!prefix || !*prefix)
-		{
+		if(!prefix || !*prefix) {
 			if(etcpath)
 				prefix = ETC_PREFIX;
 			else
@@ -512,11 +494,10 @@ retry:
 			etctest = true;
 			if(!stricmp(ETC_PREFIX, ETC_CONFDIR))
 				etcpath = true;
-		}	
+		}
 #else
 
-		if(!prefix || !*prefix)
-		{
+		if(!prefix || !*prefix) {
 			etctest = true;
 			prefix = ETC_PREFIX;
 		}
@@ -532,8 +513,7 @@ retry:
 			*cp = '/';
 
 		cp = path + strlen(path) - 1;
-		if(*cp != '/')
-		{
+		if(*cp != '/') {
 			*(++cp) = '/';
 			*(++cp) = 0;
 		}
@@ -567,11 +547,10 @@ retry:
 
 	ino.st_uid = (unsigned)-1;
 
-	if(stat(path, &ino) < 0 && etctest && !etcpath)
-	{
+	if(stat(path, &ino) < 0 && etctest && !etcpath) {
 		etcpath = true;
 		goto retry;
-	}		
+	}
 
 	// if root, make sure root owned config...
 
@@ -582,7 +561,7 @@ retry:
 
 	if(!geteuid() && !etctest)
 		return;
-		
+
 #endif
 	loadFile(path, seek, pre);
 }
@@ -601,8 +580,7 @@ void Keydata::loadFile(const char *path, const char *keys, const char *pre)
 	else
 		seek[0] = 0;
 
-	if(strcmp(path, lastpath))
-	{
+	if(strcmp(path, lastpath)) {
 		endKeydata();
 		if(canAccess(path))
 			cfgFile->open(path, ios::in);
@@ -613,19 +591,16 @@ void Keydata::loadFile(const char *path, const char *keys, const char *pre)
 		setString(lastpath, sizeof(lastpath), path);
 	}
 
-	if(link != sequence)
-	{
+	if(link != sequence) {
 		link = sequence;
 		++count;
 	}
 
 	find[0] = 0;
 	cfgFile->seekg(0);
-	while(keys && stricmp(seek, find))
-	{
+	while(keys && stricmp(seek, find)) {
 		cfgFile->getline(line, sizeof(line) - 1);
-		if(cfgFile->eof())
-		{
+		if(cfgFile->eof()) {
 			lastpath[0] = 0;
 			cfgFile->close();
 			cfgFile->clear();
@@ -648,10 +623,8 @@ void Keydata::loadFile(const char *path, const char *keys, const char *pre)
 		setString(find, 32, ++cp);
 	}
 
-	for(;;)
-	{
-		if(cfgFile->eof())
-		{
+	for(;;) {
+		if(cfgFile->eof()) {
 			lastpath[0] = 0;
 			cfgFile->close();
 			cfgFile->clear();
@@ -671,10 +644,8 @@ void Keydata::loadFile(const char *path, const char *keys, const char *pre)
 			return;
 
 		fpos = 0;
-		while(*cp && *cp != '=')
-		{
-			if(*cp == ' ' || *cp == '\t')
-			{
+		while(*cp && *cp != '=') {
+			if(*cp == ' ' || *cp == '\t') {
 				++cp;
 				continue;
 			}
@@ -691,22 +662,19 @@ void Keydata::loadFile(const char *path, const char *keys, const char *pre)
 			++cp;
 
 		ep = cp + strlen(cp);
-		while((--ep) > cp)
-		{
+		while((--ep) > cp) {
 			if(*ep == ' ' || *ep == '\t' || *ep == '\n')
 				*ep = 0;
 			else
 				break;
 		}
 
-		if(*cp == *ep && (*cp == '\'' || *cp == '\"'))
-		{
+		if(*cp == *ep && (*cp == '\'' || *cp == '\"')) {
 			++cp;
 			*ep = 0;
 		}
 
-		if(pre)
-		{
+		if(pre) {
 #ifdef HAVE_SNPRINTF
 			snprintf(buffer, 256, "%s.%s", pre, find);
 #else
@@ -723,16 +691,15 @@ void Keydata::loadFile(const char *path, const char *keys, const char *pre)
 
 void Keydata::unlink(void)
 {
-	if(link != sequence)
-	{
+	if(link != sequence) {
 		link = 0;
 		return;
 	}
-	
+
 	link = 0;
 	--count;
 }
-			
+
 void Keydata::end(void)
 {
 	Keydata::count = 0;
@@ -743,8 +710,7 @@ void Keydata::end(void)
 	Keydata::lastpath[0] = 0;
 	if(!Keydata::cfgFile)
 		Keydata::cfgFile = new std::ifstream();
-	else if(Keydata::cfgFile->is_open())
-	{
+	else if(Keydata::cfgFile->is_open()) {
 		Keydata::cfgFile->close();
 		Keydata::cfgFile->clear();
 	}
