@@ -4,24 +4,24 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -69,15 +69,14 @@ bool Lockfile::lock(const char *name)
 {
 	char mname[65];
 	char *ext = strrchr((char *)name, '/');
-	
+
 	if(ext)
 		name = ++ext;
-	
+
 	unlock();
 	snprintf(mname, sizeof(mname) - 4, "_lock_%s", name);
 	ext = strrchr(mname, '.');
-	if(ext && !stricmp(ext, ".lock"))
-	{
+	if(ext && !stricmp(ext, ".lock")) {
 		*ext = 0;
 		ext = NULL;
 	}
@@ -135,22 +134,19 @@ bool Lockfile::lock(const char *name)
 	else
 		ext = strrchr(name, '.');
 
-	if(strchr(name, '/'))
-	{
+	if(strchr(name, '/')) {
 		_path = new char[strlen(name) + 1];
 		strcpy(_path, name);
 	}
-	else if(ext && !stricmp(ext, ".pid"))
-	{
+	else if(ext && !stricmp(ext, ".pid")) {
 		if(stat("/var/run", &ino))
 			snprintf(buffer, sizeof(buffer), "/tmp/.%s", name);
 		else
 			snprintf(buffer, sizeof(buffer), "/var/run/%s", name);
 		_path = new char[strlen(buffer) + 1];
 		strcpy(_path, buffer);
-	}	
-	else
-	{
+	}
+	else {
 		if(!ext)
 			ext = ".lock";
 		if(stat("/var/lock", &ino))
@@ -162,11 +158,9 @@ bool Lockfile::lock(const char *name)
 		strcpy(_path, buffer);
 	}
 
-	for(;;)
-	{
+	for(;;) {
 		fd = ::open(_path, O_WRONLY | O_CREAT | O_EXCL, 0660);
-		if(fd > 0)
-		{
+		if(fd > 0) {
 			pid = getpid();
 			snprintf(buffer, sizeof(buffer), "%d\n", pid);
 			if(::write(fd, buffer, strlen(buffer)))
@@ -174,15 +168,13 @@ bool Lockfile::lock(const char *name)
 			::close(fd);
 			return rtn;
 		}
-		if(fd < 0 && errno != EEXIST)
-		{
+		if(fd < 0 && errno != EEXIST) {
 			delete[] _path;
 			return false;
 		}
 
 		fd = ::open(_path, O_RDONLY);
-		if(fd < 0)
-		{
+		if(fd < 0) {
 			if(errno == ENOENT)
 				continue;
 			delete[] _path;
@@ -191,26 +183,22 @@ bool Lockfile::lock(const char *name)
 
 		Thread::sleep(2000);
 		status = ::read(fd, buffer, sizeof(buffer) - 1);
-		if(status < 1)
-		{
+		if(status < 1) {
 			::close(fd);
 			continue;
 		}
 
 		buffer[status] = 0;
 		pid = atoi(buffer);
-		if(pid)
-		{
-			if(pid == getpid())
-			{
+		if(pid) {
+			if(pid == getpid()) {
 				status = -1;
 				errno = 0;
 			}
 			else
 				status = kill(pid, 0);
 
-			if(!status || (errno == EPERM))
-			{
+			if(!status || (errno == EPERM)) {
 				::close(fd);
 				delete[] _path;
 				return false;
@@ -219,17 +207,16 @@ bool Lockfile::lock(const char *name)
 		::close(fd);
 		::unlink(_path);
 	}
-}		
+}
 
 void Lockfile::unlock(void)
 {
-	if(_path)
-	{
+	if(_path) {
 		remove(_path);
 		delete[] _path;
 		_path = NULL;
 	}
-}	
+}
 
 bool Lockfile::isLocked(void)
 {
