@@ -19,9 +19,9 @@
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -83,8 +83,7 @@ void MIMEMultipart::body(std::ostream *out)
 {
 	MIMEItemPart *item = first;
 
-	while(item)
-	{
+	while(item) {
 		*out << "--" << boundry << "\r\n";
 		item->head(out);
 		*out << "\r\n";
@@ -97,8 +96,7 @@ void MIMEMultipart::body(std::ostream *out)
 
 MIMEItemPart::MIMEItemPart(MIMEMultipart *m, const char *ct)
 {
-	if(m->last)
-	{
+	if(m->last) {
 		m->last->next = this;
 		m->last = this;
 	}
